==> qbittorrent_2.9.8.orig.tar.xz: qbittorrent-2.9.8/src/rss/rssfile.h <==
/*
 * Bittorrent Client using Qt4 and libtorrent.
 * Copyright (C) 2010  Christophe Dumez, Arnaud Demaiziere
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * Contact: chris@qbittorrent.org, arnaud@qbittorrent.org
 */

#ifndef RSSFILE_H
#define RSSFILE_H

#include <QList>
#include <QStringList>

class RssArticle;
class RssFolder;

class IRssFile {

public:
  enum FileType {FEED, FOLDER};

  virtual ~IRssFile() {}

  virtual uint unreadCount() const = 0;
  virtual FileType type() const = 0;
  virtual QString displayName() const = 0;
  virtual QString id() const = 0;
  virtual void rename(const QString &new_name) = 0;
  virtual void markAsRead() = 0;
  virtual RssFolder* parent() const = 0;
  virtual void setParent(RssFolder* parent) = 0;
  virtual void refresh() = 0;
  virtual void removeAllSettings() = 0;
  virtual void saveItemsToDisk() = 0;
  virtual const QList<RssArticle> articleList() const = 0;
  virtual const QList<RssArticle> unreadArticleList() const = 0;
  QStringList pathHierarchy() const;
};

#endif // RSSFILE_H

==> qbittorrent_3.0.11.orig.tar.xz: qbittorrent-3.0.11/src/rss/rssfile.h <==
/*
 * Bittorrent Client using Qt4 and libtorrent.
 * Copyright (C) 2010  Christophe Dumez, Arnaud Demaiziere
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * Contact: chris@qbittorrent.org, arnaud@qbittorrent.org
 */

#ifndef RSSFILE_H
#define RSSFILE_H

#include <QList>
#include <QStringList>
#include <QSharedPointer>

class RssFolder;
class RssFile;
class RssArticle;

typedef QSharedPointer<RssFile> RssFilePtr;
typedef QSharedPointer<RssArticle> RssArticlePtr;
typedef QList<RssArticlePtr> RssArticleList;
typedef QList<RssFilePtr> RssFileList;

/**
 * Parent interface for RssFolder and RssFeed.
 */
class RssFile {
public:
  virtual ~RssFile() {}

  virtual uint unreadCount() const = 0;
  virtual QString displayName() const = 0;
  virtual QString id() const = 0;
  virtual void rename(const QString &new_name) = 0;
  virtual void markAsRead() = 0;
  virtual RssFolder* parent() const = 0;
  virtual void setParent(RssFolder* parent) = 0;
  virtual void refresh() = 0;
  virtual RssArticleList articleList() const = 0;
  virtual RssArticleList unreadArticleList() const = 0;
  virtual void removeAllSettings() = 0;
  virtual void saveItemsToDisk() = 0;
  QStringList pathHierarchy() const;
};

#endif // RSSFILE_H
